aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/x11.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/x11.c b/src/x11.c
index ce0bf0b..07642fc 100644
--- a/src/x11.c
+++ b/src/x11.c
@@ -880,8 +880,8 @@ translateKey(PuglView* const view, XEvent* const xevent, PuglEvent* const event)
event->key.keycode = xevent->xkey.keycode;
- // Mask off the shift bit to get the lowercase "main" symbol
- xevent->xkey.state = xevent->xkey.state & ~(unsigned)ShiftMask;
+ // Mask off the control and shift bits to get the lowercase "main" symbol
+ xevent->xkey.state = xevent->xkey.state & ~(unsigned)(ControlMask|ShiftMask);
// Lookup unshifted key
char ustr[8] = {0};